@@ -61,6 +61,14 @@ requireInDateRange <- function(cohort,
     dplyr::compute(name = name, temporary = FALSE) |>
     omopgenerics::newCohortTable(.softValidation = TRUE)
 
+  useIndexes <- getOption("CohortConstructor.use_indexes")
+  if (!isFALSE(useIndexes)) {
+    addIndex(
+      cohort = cohort,
+      cols = c("subject_id", "cohort_start_date")
+    )
+  }
+
   return(cohort)
 }
 
@@ -119,8 +127,8 @@ trimToDateRange <- function(cohort,
         startDate = startDate,
         endDate = endDate,
         minDate = dateRange[1]
-      ) %>%
-      dplyr::compute(name = name, temporary = FALSE) %>%
+      ) |>
+      dplyr::compute(name = name, temporary = FALSE) |>
       omopgenerics::recordCohortAttrition(reason = paste0(startDate, " >= ", dateRange[1]),
                                           cohortId = cohortId)
   }
@@ -133,8 +141,8 @@ trimToDateRange <- function(cohort,
         startDate = startDate,
         endDate = endDate,
         maxDate = dateRange[2]
-      ) %>%
-      dplyr::compute(name = name, temporary = FALSE) %>%
+      ) |>
+      dplyr::compute(name = name, temporary = FALSE) |>
       omopgenerics::recordCohortAttrition(reason = paste0(endDate, " <= ", dateRange[2]),
                                           cohortId = cohortId)
   }
@@ -143,6 +151,14 @@ trimToDateRange <- function(cohort,
     dplyr::compute(name = name, temporary = FALSE) |>
     omopgenerics::newCohortTable(.softValidation = TRUE)
 
+  useIndexes <- getOption("CohortConstructor.use_indexes")
+  if (!isFALSE(useIndexes)) {
+    addIndex(
+      cohort = cohort,
+      cols = c("subject_id", "cohort_start_date")
+    )
+  }
+
   return(cohort)
 }
 
@@ -151,7 +167,7 @@ trimStartDate <- function(cohort,
                           endDate,
                           minDate,
                           requirementIds) {
-  cohort <- cohort %>%
+  cohort <- cohort |>
     dplyr::mutate(
       !!startDate := dplyr::if_else(
         .data[[startDate]] <= !!minDate &
@@ -159,7 +175,7 @@ trimStartDate <- function(cohort,
         as.Date(minDate),
         .data[[startDate]]
       )
-    ) %>%
+    ) |>
     dplyr::filter(.data[[startDate]] <= .data[[endDate]] |
                     (!.data$cohort_definition_id %in% .env$requirementIds))
   return(cohort)
@@ -170,13 +186,13 @@ trimEndDate <- function(cohort,
                         endDate,
                         maxDate,
                         requirementIds) {
-  cohort <- cohort %>%
+  cohort <- cohort |>
     dplyr::mutate(!!endDate := dplyr::if_else(
       .data[[endDate]] >= !!maxDate &
         (.data$cohort_definition_id %in% .env$requirementIds),
       as.Date(maxDate),
       .data[[endDate]]
-    )) %>%
+    )) |>
     dplyr::filter(.data[[startDate]] <= .data[[endDate]] |
                     (!.data$cohort_definition_id %in% requirementIds))
   return(cohort)
